<!-- Open Graph meta tags generated by OG Pilot -->
<meta property="og:title" content="{{ title }}" />
{% if description %}<meta property="og:description" content="{{ description }}" />{% endif %}
<meta property="og:image" content="{{ image_url }}" />
<meta property="og:type" content="website" />
{% if site_name %}<meta property="og:site_name" content="{{ site_name }}" />{% endif %}

<!-- Twitter Card meta tags -->
<meta name="twitter:card" content="summary_large_image" />
<meta name="twitter:title" content="{{ title }}" />
{% if description %}<meta name="twitter:description" content="{{ description }}" />{% endif %}
<meta name="twitter:image" content="{{ image_url }}" />
